# Generated by Django 3.0.5 on 2020-05-03 03:12

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('countries', '0001_initial'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='country',
            options={'permissions': (('list_country', 'Can list countries'),)},
        ),
    ]



# Generated by Django 3.0.6 on 2020-05-28 04:02

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('app_configurations', '0002_auto_20200411_0132'),
    ]

    operations = [
        migrations.AlterField(
            model_name='generalinfoconfiguration',
            name='address',
            field=models.TextField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='generalinfoconfiguration',
            name='application_name',
            field=models.CharField(default='App. Name', max_length=50, null=True),
        ),
        migrations.AlterField(
            model_name='generalinfoconfiguration',
            name='contact_emails',
            field=models.TextField(blank=True, null=True),
        ),
    ]



# Generated by Django 3.0.5 on 2020-04-02 16:51

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('auth', '0011_update_proxy_permissions'),
    ]

    operations = [
        migrations.CreateModel(
            name='PermissionPlus',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(blank=True, max_length=200, null=True)),
                ('active', models.BooleanField(default=False)),
                ('permission', models.OneToOneField(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='plus', to='auth.Permission')),
            ],
        ),
    ]



from rest_framework import routers
from .views import (
    UserViewSet,
    LoginViewSet
)

router = routers.DefaultRouter()
router.register(r'authentication', LoginViewSet)
router.register(r'users', UserViewSet)



# Generated by Django 3.0.5 on 2020-04-02 13:00

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('users_extended', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='extendeduser',
            name='security_pin',
            field=models.CharField(max_length=300, null=True),
        ),
    ]



# Generated by Django 3.0.5 on 2020-04-02 12:53

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion
import imagekit.models.fields
import users_extended.models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='ExtendedUser',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('profile_image', imagekit.models.fields.ProcessedImageField(blank=True, null=True, upload_to=users_extended.models.ExtendedUser.profile_image_upload_to)),
                ('security_pin', models.PositiveIntegerField(null=True)),
                ('security_qr', models.CharField(max_length=300, null=True)),
                ('user', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='extended_user', to=settings.AUTH_USER_MODEL)),
            ],
        ),
    ]



from django.db import models
from django.contrib.auth.models import Permission


class PermissionPlus(models.Model):
    permission = models.OneToOneField(Permission, related_name='plus', null=True, blank=True, on_delete=models.PROTECT)
    name = models.CharField(null=True, blank=True, max_length=200)
    active = models.BooleanField(default=False)

    class Meta:
        permissions = (
            ('list_permission', 'Can list permission'),
            ('list_group', 'Can list group'),
        )



# Generated by Django 3.0.5 on 2020-05-03 00:05

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Country',
            fields=[
                ('id', models.PositiveIntegerField(primary_key=True, serialize=False)),
                ('name', models.CharField(max_length=200)),
                ('iso3', models.CharField(max_length=3)),
                ('iso2', models.CharField(max_length=2)),
                ('phone_code', models.PositiveIntegerField()),
                ('currency', models.CharField(max_length=3)),
            ],
        ),
        migrations.CreateModel(
            name='State',
            fields=[
                ('id', models.PositiveIntegerField(primary_key=True, serialize=False)),
                ('name', models.CharField(max_length=200)),
                ('state_code', models.CharField(max_length=3)),
                ('country', models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, to='countries.Country')),
            ],
        ),
        migrations.CreateModel(
            name='City',
            fields=[
                ('id', models.PositiveIntegerField(primary_key=True, serialize=False)),
                ('name', models.CharField(max_length=200)),
                ('state', models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, to='countries.State')),
            ],
        ),
    ]



class CustomSerializerMixin(object):
    def __init__(self, instance=None, *args, **kwargs):
        context = kwargs.get('context', None)
        if context:
            fields_to_removel = context.get('remove_fields', None)
            if fields_to_removel:
                existing = set(self.fields.keys())
                for field_name in fields_to_removel:
                    if field_name in existing:
                        self.fields.pop(field_name)
        super().__init__(instance, *args, **kwargs)



# Generated by Django 3.0.5 on 2020-04-25 14:10

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('users_extended', '0008_auto_20200422_1706'),
    ]

    operations = [
        migrations.AddField(
            model_name='extendeduser',
            name='multi_sessions',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='extendeduser',
            name='multi_sessions_qty',
            field=models.PositiveIntegerField(default=0),
        ),
    ]



# Generated by Django 3.0.5 on 2020-04-04 16:00

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('permissions', '0001_initial'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='permissionplus',
            options={'permissions': (('list_permission', 'Can list permission'), ('list_group', 'Can list group'))},
        ),
    ]



from rest_framework import viewsets
from rest_framework.response import Response
from utils.permissions.permissions_utilities import DjangoModelPermissionsFull
from rest_framework.exceptions import ValidationError
from .serializers import GeneralInfoConfigurationSerializer
from .models import GeneralInfoConfiguration


class AppConfiguracionViewSet(viewsets.ViewSet):
    def list(self, request):
        from .services import create_update_general_info
        general_info_configuration = GeneralInfoConfiguration.objects
        general_info_configuration = general_info_configuration.first() if general_info_configuration.exists() else create_update_general_info()
        return Response({
            "general_info_configuration": GeneralInfoConfigurationSerializer(general_info_configuration,
                                                                             context={'request': request}).data,
        })


class AppGeneralInfoConfigurationViewSet(AppConfiguracionViewSet, viewsets.ModelViewSet):
    permission_classes = [DjangoModelPermissionsFull]
    queryset = GeneralInfoConfiguration.objects.all()
    serializer_class = GeneralInfoConfigurationSerializer

    def create(self, request, *args, **kwargs):
        raise ValidationError({'_error': 'Metodo crear no disponible'})

    def destroy(self, request, *args, **kwargs):
        raise ValidationError({'_error': 'Metodo eliminar no disponible'})

    def list(self, request):
        return super().list(request)



from rest_framework import serializers
from .models import GeneralInfoConfiguration


class GeneralInfoConfigurationSerializer(serializers.ModelSerializer):
    icon_small = serializers.ImageField(read_only=True)
    icon_medium = serializers.ImageField(read_only=True)
    logo_small = serializers.ImageField(read_only=True)
    logo_medium = serializers.ImageField(read_only=True)
    favicon_medium = serializers.ImageField(read_only=True)
    favicon_small = serializers.ImageField(read_only=True)

    def update(self, instance, validated_data):
        logo = validated_data.get('logo', None)
        favicon = validated_data.get('favicon', None)
        application_name = validated_data.get('application_name', None)

        address = validated_data.get('address', None)
        contact_emails = validated_data.get('contact_emails', None)
        attention_schedule = validated_data.get('attention_schedule', None)
        facebook = validated_data.get('facebook', None)
        whatsaap = validated_data.get('whatsaap', None)
        instagram = validated_data.get('instagram', None)
        linkedin = validated_data.get('linkedin', None)
        youtube = validated_data.get('youtube', None)
        twitter = validated_data.get('twitter', None)

        from .services import create_update_general_info
        configuracion = create_update_general_info(
            logo=logo,
            application_name=application_name,
            favicon=favicon,
            twitter=twitter,
            youtube=youtube,
            linkedin=linkedin,
            instagram=instagram,
            whatsaap=whatsaap,
            facebook=facebook,
            attention_schedule=attention_schedule,
            contact_emails=contact_emails,
            address=address
        )
        return configuracion

    class Meta:
        model = GeneralInfoConfiguration
        fields = [
            'id',
            'logo',
            'application_name',
            'address',
            'contact_emails',
            'attention_schedule',
            'facebook',
            'whatsaap',
            'instagram',
            'linkedin',
            'youtube',
            'twitter',
            'icon_small',
            'icon_medium',
            'logo_small',
            'logo_medium',
            'favicon',
            'favicon_medium',
            'favicon_small',
        ]



# Generated by Django 3.0.5 on 2020-04-22 13:24

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('users_extended', '0006_auto_20200405_2103'),
    ]

    operations = [
        migrations.AddField(
            model_name='extendeduser',
            name='alias',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
    ]
